@@ -224,6 +224,11 @@ def block_tools(request,vrf_id,prefix):
 ## Columns are: ip,fqdn,description,tt
 ##
 def download_ips(request,vrf_id,prefix):
+    def to_utf8(x):
+        if x:
+            return x.encode("utf8")
+        else:
+            return ""
     assert is_cidr(prefix)
     vrf_id=int(vrf_id)
     vrf=get_object_or_404(VRF,id=vrf_id)
@@ -233,7 +238,7 @@ def download_ips(request,vrf_id,prefix):
     out=cStringIO.StringIO()
     writer=csv.writer(out)
     for a in block.addresses:
-        writer.writerow([a.ip,a.fqdn,a.description,a.tt])
+        writer.writerow([a.ip,a.fqdn,to_utf8(a.description),a.tt])
     return HttpResponse(out.getvalue(),mimetype="text/csv")
 ##
 ## Upload allocated IPs in CSV format
