@@ -84,3 +84,8 @@ class temporary_file(object):
         return self.p
     def __exit__(self, type, value, tb):
         os.unlink(self.p)
+##
+## Check file is inside dir
+##
+def in_dir(file,dir):
+    return os.path.commonprefix([dir,os.path.normpath(file)])==dir
