@@ -14,6 +14,7 @@ from noc.sa.periodic import periodic_registry
 from noc.sa.script import script_registry
 from noc.sa.protocols.sae_pb2 import TELNET,SSH,HTTP
 from noc.main.menu import Menu
+from noc.main.search import SearchResult
 
 profile_registry.register_all()
 periodic_registry.register_all()
@@ -63,9 +64,10 @@ class ManagedObject(models.Model):
         verbose_name_plural="Managed Objects"
     name=models.CharField("Name",max_length=64,unique=True)
     is_managed=models.BooleanField("Is Managed?",default=True)
-    administrative_domain=models.ForeignKey(AdministrativeDomain,verbose_name="AdministrativeDomain")
+    administrative_domain=models.ForeignKey(AdministrativeDomain,verbose_name="Administrative Domain")
     activator=models.ForeignKey(Activator,verbose_name="Activator")
     profile_name=models.CharField("Profile",max_length=128,choices=profile_registry.choices)
+    description=models.CharField("Description",max_length=256,null=True,blank=True)
     # Access
     scheme=models.IntegerField("Scheme",choices=scheme_choices)
     address=models.CharField("Address",max_length=64)
@@ -164,6 +166,20 @@ class ManagedObject(models.Model):
         if config:
             config.delete()
         super(ManagedObject,self).delete()
+    ##
+    ## Search engine
+    ##
+    @classmethod
+    def search(cls,user,query,limit):
+        q=Q(repo_path__icontains=query)|Q(name__icontains=query)|Q(address__icontains=query)|Q(user__icontains=query)|Q(description__icontains=query)
+        for o in [o for o in cls.objects.filter(q) if o.has_access(user)]:
+            relevancy=1.0
+            yield SearchResult(
+                url="/admin/sa/managedobject/%d/"%o.id,
+                title="SA: "+unicode(o),
+                text=unicode(o),
+                relevancy=relevancy
+            )
 
 ##
 ##
