@@ -86,9 +86,9 @@ def tools(request):
 ##
 ## List of CSV file fields
 ##
-MO_IMPORT_CSV_FIELDS=["name","profile_name","scheme","address","port","user","password","super_password","remote_path",
+MO_IMPORT_CSV_FIELDS=["name","profile_name","description","scheme","address","port","user","password","super_password","remote_path",
     "trap_source_ip","trap_community","snmp_ro","snmp_rw","repo_path"]
-MO_IMPORT_REQUIRED_CSV_FIELDS=["name","profile_name","scheme","address"]
+MO_IMPORT_REQUIRED_CSV_FIELDS=["name","profile_name","scheme","address","repo_path"]
 SCHEME=dict([(x[1],x[0]) for x in scheme_choices])
 ##
 ## Upload managed objects from a CSV file
@@ -154,7 +154,7 @@ def upload_managed_objects(request):
             activator=form.cleaned_data["activator"]
             count,error=upload_csv(request.FILES['file'])
             if error:
-                return render_failure("Managed Object Upload Failure",error)
+                return render_failure(request,"Managed Object Upload Failure",error)
             else:
                 return render_success(request,"Managed Objects are Uploaded","%d managed objects uploaded/updated"%count)
     return HttpResponseRedirect("/sa/tools/")
